@@ -1,5 +1,5 @@
 package ZMQ::FFI::ContextRole;
-$ZMQ::FFI::ContextRole::VERSION = '1.10';
+$ZMQ::FFI::ContextRole::VERSION = '1.12';
 use Moo::Role;
 
 use ZMQ::FFI::Util qw(current_tid);
@@ -44,12 +44,15 @@ has sockets => (
 );
 
 requires qw(
+    init
     get
     set
     socket
     proxy
     device
     destroy
+    curve_keypair
+    has_capability
 );
 
 1;
@@ -66,7 +69,7 @@ ZMQ::FFI::ContextRole
 
 =head1 VERSION
 
-version 1.10
+version 1.12
 
 =head1 AUTHOR
 
@@ -74,7 +77,7 @@ Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dylan Cali.
+This software is copyright (c) 2019 by Dylan Cali.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
