@@ -1,7 +1,6 @@
 package ZMQ::FFI::Custom::Raw;
-$ZMQ::FFI::Custom::Raw::VERSION = '1.16_01'; # TRIAL
-
-$ZMQ::FFI::Custom::Raw::VERSION = '1.1601';sub load {
+$ZMQ::FFI::Custom::Raw::VERSION = '1.12';
+sub load {
     my ($soname) = @_;
 
     my $ffi    = FFI::Platypus->new( lib => $soname // 'libzmq.so' );
@@ -70,7 +69,7 @@ ZMQ::FFI::Custom::Raw
 
 =head1 VERSION
 
-version 1.16_01
+version 1.12
 
 =head1 AUTHOR
 
