@@ -1,7 +1,6 @@
 package ZMQ::FFI::ZMQ4::Raw;
-$ZMQ::FFI::ZMQ4::Raw::VERSION = '1.16_01'; # TRIAL
-
-$ZMQ::FFI::ZMQ4::Raw::VERSION = '1.1601';use FFI::Platypus;
+$ZMQ::FFI::ZMQ4::Raw::VERSION = '1.12';
+use FFI::Platypus;
 
 sub load {
     my ($soname) = @_;
@@ -150,7 +149,7 @@ ZMQ::FFI::ZMQ4::Raw
 
 =head1 VERSION
 
-version 1.16_01
+version 1.12
 
 =head1 AUTHOR
 
